@@ -215,10 +215,10 @@ class Env:
         :param flags: the flags to remove
         """
 
-        for f in flags:
+        for flag in flags:
             assert isinstance(self._vars[var], list)
-            if f in self._vars[var]:
-                self._vars[var].remove(f)
+            if flag in self._vars[var]:
+                self._vars[var].remove(flag)
 
     def sub_build(self, gen: Generator, dir: str):
         """
@@ -252,8 +252,8 @@ class Env:
         gen._add_build_file(self.cur_dir + '/build.py')
 
         mod_path = self.cur_dir[2:].replace('/', '.')
-        b = importlib.import_module(mod_path + '.build')
-        b.build(gen, self)
+        sub = importlib.import_module(mod_path + '.build')
+        sub.build(gen, self)
 
         self._cwd.path = old_cwd
 
@@ -425,7 +425,7 @@ class Env:
         flags += ' ' + ' '.join(['-I' + i for i in self['CPPPATH']])
         return self._cc(gen, out, ins, flags)
 
-    def cc(self, gen: Generator, out: str, ins: list[str]) -> BuildPath:
+    def cc(self, gen: Generator, out: str, ins: list[str]) -> BuildPath:  # pylint: disable=C0103
         """
         Runs the C compiler on the given input files
 
@@ -611,7 +611,7 @@ class Env:
         return lib
 
     def c_exe(self, gen: Generator, out: str, ins: list[str],
-              libs: list[str] = [], deps: list[str] = []) -> BuildPath:
+              libs: list[str] = None, deps: list[str] = None) -> BuildPath:
         """
         Produces a C executable from given input files
 
@@ -636,10 +636,12 @@ class Env:
         The `BuildPath` to the produced executable
         """
 
+        libs = [] if libs is None else libs
+        deps = [] if deps is None else deps
         return self._c_cxx_exe(gen, out, ins, libs, deps, self['CC'])
 
     def cxx_exe(self, gen: Generator, out: str, ins: list[str],
-                libs: list[str] = [], deps: list[str] = []) -> BuildPath:
+                libs: list[str] = None, deps: list[str] = None) -> BuildPath:
         """
         Produces a C++ executable from given input files
 
@@ -664,6 +666,8 @@ class Env:
         The `BuildPath` to the produced executable
         """
 
+        libs = [] if libs is None else libs
+        deps = [] if deps is None else deps
         return self._c_cxx_exe(gen, out, ins, libs, deps, self['CXX'])
 
     def _c_cxx_exe(self, gen: Generator, out: str, ins: list[str],
@@ -692,7 +696,7 @@ class Env:
         gen.add_build(edge)
         return bin
 
-    def rust_lib(self, gen: Generator, out: str, deps: list[str] = []) -> BuildPath:
+    def rust_lib(self, gen: Generator, out: str, deps: list[str] = None) -> BuildPath:
         """
         Produces a Rust library
 
@@ -722,9 +726,10 @@ class Env:
         The `BuildPath` to the produced static library
         """
 
+        deps = [] if deps is None else deps
         return self.rust(gen, ['lib' + out + '.a'], deps)[0]
 
-    def rust_exe(self, gen: Generator, out: str, deps: list[str] = []) -> BuildPath:
+    def rust_exe(self, gen: Generator, out: str, deps: list[str] = None) -> BuildPath:
         """
         Produces a Rust executable
 
@@ -754,6 +759,7 @@ class Env:
         The `BuildPath` to the produced executable
         """
 
+        deps = [] if deps is None else deps
         return self.rust(gen, [out], deps)[0]
 
     def rust(self, gen: Generator, outs: list[str], deps: list[str]) -> [BuildPath]:
@@ -791,7 +797,7 @@ class Env:
         try:
             idx = self['CRGFLAGS'].index('--target')
             target_dir = self['CRGFLAGS'][idx + 1] + '/'
-        except:
+        except ValueError:
             pass
 
         # determine destination directory
