@@ -84,8 +84,8 @@ class BuildEdge:
     the output files. Additional dependencies can be specified to also trigger a rebuild.
     """
 
-    def __init__(self, rule: str, outs: list[str], ins: list[str], deps: list[str] = [],
-                 vars: dict[str, str] = {}, libs: list[str] = [], lib_path: list[str] = []):
+    def __init__(self, rule: str, outs: list[str], ins: list[str], deps: list[str] = None,
+                 vars: dict[str, str] = None, libs: list[str] = None, lib_path: list[str] = None):
         """
         Creates a new build edge.
 
@@ -102,6 +102,11 @@ class BuildEdge:
 
         assert len(outs) > 0, "The list of output files cannot be empty"
 
+        deps = [] if deps is None else deps
+        vars = {} if vars is None else vars
+        libs = [] if libs is None else libs
+        lib_path = [] if lib_path is None else lib_path
+
         self.calltrace = None
         self.rule = rule
         self.outs = outs
@@ -131,9 +136,9 @@ class BuildEdge:
         if len(self.deps) > 0:
             file.write(' | %s' % (' '.join(self.deps)))
         file.write('\n')
-        for k, v in self.vars.items():
-            if k not in defaults or defaults[k] != v:
-                file.write('  %s = %s\n' % (k, v))
+        for key, val in self.vars.items():
+            if key not in defaults or defaults[key] != val:
+                file.write('  %s = %s\n' % (key, val))
 
 
 class Generator:
@@ -253,11 +258,11 @@ class Generator:
         assert edge.rule in self._rules
 
         if self._debug:
-            for b in self._build_edges:
-                for o in edge.outs:
-                    assert o not in b.outs, \
+            for ex_edge in self._build_edges:
+                for out in ex_edge.outs:
+                    assert out not in ex_edge.outs, \
                         "Output '{}' is already produced by the build edge added here:\n{}".format(
-                            o, ''.join(traceback.format_list(b.calltrace)))
+                            out, ''.join(traceback.format_list(ex_edge.calltrace)))
             edge.calltrace = traceback.extract_stack()
 
         self._rules[edge.rule].refs += 1
@@ -330,17 +335,17 @@ class Generator:
             defaults = self._determine_defaults()
 
         # generate build.ninja
-        with open(build_file, 'w') as file:
+        with open(build_file, 'w', encoding='utf-8') as file:
             file.write('# This file has been generated by the ninjapie build system.\n')
             file.write('\n')
 
-            for k, v in defaults.items():
-                file.write('%s = %s\n' % (k, v))
+            for key, val in defaults.items():
+                file.write('%s = %s\n' % (key, val))
             file.write('\n')
 
-            for n, r in self._rules.items():
-                if r.refs > 0:
-                    r._write_to_file(n, file)
+            for name, rule in self._rules.items():
+                if rule.refs > 0:
+                    rule._write_to_file(name, file)
             file.write('\n')
 
             # separate pool for the build.ninja regeneration to run that alone
@@ -348,18 +353,18 @@ class Generator:
             file.write('  depth = 1\n')
             file.write('\n')
 
-            for b in self._build_edges:
-                b._write_to_file(defaults, file)
+            for edge in self._build_edges:
+                edge._write_to_file(defaults, file)
 
         # generate deps of build.ninja
         build_files = ['build.py'] + self._build_files
-        with open(dep_file, 'w') as file:
+        with open(dep_file, 'w', encoding='utf-8') as file:
             file.write(build_file + ': ' + ' '.join(build_files))
 
         # generate files with all globs
-        with open(glob_file, 'w') as file:
-            for g in self._globs:
-                file.write(g + '\n')
+        with open(glob_file, 'w', encoding='utf-8') as file:
+            for glb in self._globs:
+                file.write(glb + '\n')
 
     def write_compile_cmds(self):
         """
@@ -373,21 +378,21 @@ class Generator:
         outdir = self._build_dir
 
         # generate compile_commands.json for clangd
-        with open(outdir + '/compile_commands.json', 'w') as cmds:
+        with open(outdir + '/compile_commands.json', 'w', encoding='utf-8') as cmds:
             cmds.write('[\n')
             base_dir = os.getcwd()
-            c = 0
-            for b in self._build_edges:
-                if b.rule == 'cxx' or b.rule == 'cc':
-                    assert len(b.ins) == 1
-                    if c > 0:
+            count = 0
+            for edge in self._build_edges:
+                if edge.rule in ('cxx', 'cc'):
+                    assert len(edge.ins) == 1
+                    if count > 0:
                         cmds.write(',\n')
                     cmds.write('  {\n')
                     cmds.write('    "directory": "{}",\n'.format(base_dir))
-                    cmds.write('    "file": "{}",\n'.format(b.ins[0]))
-                    cmds.write('    "command": "{}"\n'.format(self._get_clang_flags(b)))
+                    cmds.write('    "file": "{}",\n'.format(edge.ins[0]))
+                    cmds.write('    "command": "{}"\n'.format(self._get_clang_flags(edge)))
                     cmds.write('  }')
-                    c += 1
+                    count += 1
             cmds.write('\n]\n')
 
     def _get_clang_flags(self, bedge: BuildEdge) -> str:
@@ -425,14 +430,14 @@ class Generator:
 
         # first count the number of times for each value and each variable
         vars = {}
-        for b in self._build_edges:
-            for k, v in b.vars.items():
-                if k not in vars:
-                    vars[k] = {}
-                if v in vars[k]:
-                    vars[k][v] += 1
+        for edge in self._build_edges:
+            for key, val in edge.vars.items():
+                if key not in vars:
+                    vars[key] = {}
+                if val in vars[key]:
+                    vars[key][val] += 1
                 else:
-                    vars[k][v] = 1
+                    vars[key][val] = 1
 
         # now use the most-used value for each variable as the default
         defaults = {}
@@ -459,17 +464,17 @@ class Generator:
         """
 
         libs = self._collect_libs()
-        for b in self._build_edges:
-            for d in b.libs:
-                stname = 'lib' + d + '.a'
-                shname = 'lib' + d + '.so'
-                for p in b.lib_path:
-                    if p in libs:
-                        if shname in libs[p]:
-                            b.deps.append(libs[p][shname])
+        for edge in self._build_edges:
+            for lib in edge.libs:
+                stname = 'lib' + lib + '.a'
+                shname = 'lib' + lib + '.so'
+                for path in edge.lib_path:
+                    if path in libs:
+                        if shname in libs[path]:
+                            edge.deps.append(libs[path][shname])
                             break
-                        elif stname in libs[p]:
-                            b.deps.append(libs[p][stname])
+                        if stname in libs[path]:
+                            edge.deps.append(libs[path][stname])
                             break
 
     def _collect_libs(self) -> dict[str, dict[str, str]]:
@@ -478,11 +483,11 @@ class Generator:
         """
 
         libs = {}
-        for b in self._build_edges:
-            for o in b.outs:
-                if o.endswith('.a') or o.endswith('.so'):
-                    dir = os.path.dirname(o)
+        for edge in self._build_edges:
+            for out in edge.outs:
+                if out.endswith('.a') or out.endswith('.so'):
+                    dir = os.path.dirname(out)
                     if dir not in libs:
                         libs[dir] = {}
-                    libs[dir][os.path.basename(o)] = o
+                    libs[dir][os.path.basename(out)] = out
         return libs
